<?php
declare(strict_types=1);

namespace IntiTest\Db\Connection;

use Doctrine\DBAL\Connection;
use Inti\Db\Connection\ConnectionManager;
use IntiTest\Db\ConfigProvider;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ServiceManager\ServiceManager;
use PHPUnit\Framework\TestCase;

/**
 * Class ConnectionManagerTest
 *
 * @package IntiTest\Db\Connection
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-db
 */
final class ConnectionFactoryTest extends TestCase
{
    public function testCanCreateConnection()
    {
        $params = [
            'driver' => 'pdo_sqlite',
            'path' => ':memory:',
        ];

        $config = (new ConfigAggregator([
            \Inti\Db\ConfigProvider::class,
            ConfigProvider::class,
            new ArrayProvider([
                'db_connections' => [
                    'test' => $params,
                ],
            ]),
        ]))->getMergedConfig();

        $config['dependencies']['services']['config'] = $config;
        $container = new ServiceManager($config['dependencies']);

        $this->assertTrue($container->has(ConnectionManager::class));

        /** @var ConnectionManager $connections */
        $connections = $container->get(ConnectionManager::class);
        $connection = $connections->get('test');

        $this->assertInstanceOf(Connection::class, $connection);
        /** @noinspection PhpInternalEntityUsedInspection */
        $this->assertEquals($params, $connection->getParams());
    }
}
